summaryrefslogtreecommitdiff
path: root/src/mongo/db/query/find.cpp
diff options
context:
space:
mode:
authorWill Buerger <will.buerger@mongodb.com>2023-05-17 11:49:47 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2023-05-17 12:58:52 +0000
commitae65ecae5514adc99d60b7396137a1acf2b44335 (patch)
tree24169f9a640321bfbbec649e869fe51b273b35e3 /src/mongo/db/query/find.cpp
parent1b4a551a6b8c85611e26857217ce1a1e1363e716 (diff)
downloadmongo-ae65ecae5514adc99d60b7396137a1acf2b44335.tar.gz
SERVER-76427 Rename $telemetry to $queryStats
Diffstat (limited to 'src/mongo/db/query/find.cpp')
-rw-r--r--src/mongo/db/query/find.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/db/query/find.cpp b/src/mongo/db/query/find.cpp
index c54138afd4b..dcd402e9c70 100644
--- a/src/mongo/db/query/find.cpp
+++ b/src/mongo/db/query/find.cpp
@@ -112,7 +112,7 @@ void endQueryOp(OperationContext* opCtx,
auto curOp = CurOp::get(opCtx);
// Fill out basic CurOp query exec properties. More metrics (nreturned and executionTime)
// are collected within collectTelemetryMongod.
curOp->debug().cursorid = (cursor.has_value() ? cursor->getCursor()->cursorid() : -1);
curOp->debug().cursorExhausted = !cursor.has_value();
curOp->debug().additiveMetrics.nBatches = 1;
@@ -125,9 +125,9 @@ void endQueryOp(OperationContext* opCtx,
curOp->setEndOfOpMetrics(numResults);
if (cursor) {
- collectTelemetryMongod(opCtx, *cursor);
+ collectQueryStatsMongod(opCtx, *cursor);
} else {
- collectTelemetryMongod(opCtx, std::move(curOp->debug().telemetryRequestShapifier));
+ collectQueryStatsMongod(opCtx, std::move(curOp->debug().queryStatsRequestShapifier));
}
if (collection) {
@@ -112,7 +112,7 @@ void endQueryOp(OperationContext* opCtx,
auto curOp = CurOp::get(opCtx);
// Fill out basic CurOp query exec properties. More metrics (nreturned and executionTime)
- // are collected within collectTelemetryMongod.
+ // are collected within collectQueryStatsMongod.
curOp->debug().cursorid = (cursor.has_value() ? cursor->getCursor()->cursorid() : -1);
curOp->debug().cursorExhausted = !cursor.has_value();